@@ -29,15 +29,13 @@
 //Added by qt3to4:
 #include <QTextStream>
 #include <QVector>
-#include <kuser.h>
+#include <QCryptographicHash>
 
-#include <kglobal.h>
+#include <kuser.h>
 #include <kio/netaccess.h>
 #include <kio/job.h>
 #include <kmessagebox.h>
 #include <kcodecs.h>
-#include <kdebug.h>
-
 #include "kexthighscore.h"
 #include "kexthighscore_gui.h"
 #include "kemailsettings.h"
@@ -124,24 +122,30 @@ int ItemArray::findIndex(const QString &name) const
 
 const ItemContainer *ItemArray::item(const QString &name) const
 {
+    QLoggingCategory::setFilterRules(QLatin1Literal("games.highscore.debug = true"));
+    
     int i = findIndex(name);
-    if ( i==-1 ) kError(11002) << "no item named \"" << name
+    if ( i==-1 ) qCCritical(GAMES_HIGHSCORE) << "no item named \"" << name
                                 << "\"";
     return at(i);
 }
 
 ItemContainer *ItemArray::item(const QString &name)
 {
+    QLoggingCategory::setFilterRules(QLatin1Literal("games.highscore.debug = true"));
+  
     int i = findIndex(name);
-    if ( i==-1 ) kError(11002) << "no item named \"" << name
+    if ( i==-1 ) qCCritical(GAMES_HIGHSCORE) << "no item named \"" << name
                                 << "\"";
     return at(i);
 }
 
 void ItemArray::setItem(const QString &name, Item *item)
 {
+    QLoggingCategory::setFilterRules(QLatin1Literal("games.highscore.debug = true"));
+  
     int i = findIndex(name);
-    if ( i==-1 ) kError(11002) << "no item named \"" << name
+    if ( i==-1 ) qCCritical(GAMES_HIGHSCORE) << "no item named \"" << name
                                 << "\"";
     bool stored = at(i)->isStored();
     bool canHaveSubGroup = at(i)->canHaveSubGroup();
@@ -151,8 +155,10 @@ void ItemArray::setItem(const QString &name, Item *item)
 void ItemArray::addItem(const QString &name, Item *item,
                         bool stored, bool canHaveSubGroup)
 {
+    QLoggingCategory::setFilterRules(QLatin1Literal("games.highscore.debug = true"));
+    
     if ( findIndex(name)!=-1 )
-        kError(11002) << "item already exists \"" << name << "\"";
+        qCCritical(GAMES_HIGHSCORE) << "item already exists \"" << name << "\"";
 
     append(new ItemContainer);
     //at(i) = new ItemContainer;
@@ -540,9 +546,9 @@ ManagerPrivate::~ManagerPrivate()
     delete _hsConfig;
 }
 
-KUrl ManagerPrivate::queryUrl(QueryType type, const QString &newName) const
+QUrl ManagerPrivate::queryUrl(QueryType type, const QString &newName) const
 {
-    KUrl url = serverURL;
+    QUrl url = serverURL;
     QString nameItem = QLatin1String( "nickname" );
     QString name = _playerInfos->registeredName();
     bool withVersion = true;
@@ -551,28 +557,33 @@ KUrl ManagerPrivate::queryUrl(QueryType type, const QString &newName) const
 
 	switch (type) {
         case Submit:
-            url.addPath(QLatin1String( "submit.php" ));
-            level = true;
+            url = url.adjusted(QUrl::StripTrailingSlash);
+	    url.setPath(url.path() + '/' + QLatin1String( "submit.php" ));
+	    level = true;
             key = true;
             break;
         case Register:
-            url.addPath(QLatin1String( "register.php" ));
-            name = newName;
+            url = url.adjusted(QUrl::StripTrailingSlash);
+	    url.setPath(url.path() + '/' + QLatin1String( "register.php" ));
+	    name = newName;
             break;
         case Change:
-            url.addPath(QLatin1String( "change.php" ));
-            key = true;
+            url = url.adjusted(QUrl::StripTrailingSlash);
+	    url.setPath(url.path() + '/' + QLatin1String( "change.php" ));
+	    key = true;
             if ( newName!=name )
                 Manager::addToQueryURL(url, QLatin1String( "new_nickname" ), newName);
             break;
         case Players:
-            url.addPath(QLatin1String( "players.php" ));
+	    url = url.adjusted(QUrl::StripTrailingSlash);
+	    url.setPath(url.path() + '/' + QLatin1String( "players.php" ));
             nameItem = QLatin1String( "highlight" );
             withVersion = false;
             break;
         case Scores:
-            url.addPath(QLatin1String( "highscores.php" ));
-            withVersion = false;
+            url = url.adjusted(QUrl::StripTrailingSlash);
+	    url.setPath(url.path() + '/' + QLatin1String( "highscores.php" ));
+	    withVersion = false;
             if ( _nbGameTypes>1 ) level = true;
             break;
 	}
@@ -611,10 +622,10 @@ const char *DUMMY_STRINGS[] = {
 const char *UNABLE_TO_CONTACT =
     I18N_NOOP("Unable to contact world-wide highscore server");
 
-bool ManagerPrivate::doQuery(const KUrl &url, QWidget *parent,
+bool ManagerPrivate::doQuery(const QUrl &url, QWidget *parent,
                                 QDomNamedNodeMap *map)
 {
-    KIO::http_update_cache(url, true, 0); // remove cache !
+    KIO::http_update_cache(url, true, QDateTime::fromTime_t(0)); // remove cache !
 
     QString tmpFile;
     if ( !KIO::NetAccess::download(url, tmpFile, parent) ) {
@@ -702,7 +713,7 @@ bool ManagerPrivate::modifySettings(const QString &newName,
     if (WWEnabled) {
         newPlayer = _playerInfos->key().isEmpty()
                     || _playerInfos->registeredName().isEmpty();
-        KUrl url = queryUrl((newPlayer ? Register : Change), newName);
+        QUrl url = queryUrl((newPlayer ? Register : Change), newName);
         Manager::addToQueryURL(url, QLatin1String( "comment" ), comment);
 
         QDomNamedNodeMap map;
@@ -839,13 +850,14 @@ bool ManagerPrivate::submitWorldWide(const Score &score,
     if ( score.type()==Lost && !trackLostGames ) return true;
     if ( score.type()==Draw && !trackDrawGames ) return true;
 
-    KUrl url = queryUrl(Submit);
+    QUrl url = queryUrl(Submit);
     manager.additionalQueryItems(url, score);
     int s = (score.type()==Won ? score.score() : (int)score.type());
     QString str =  QString::number(s);
     Manager::addToQueryURL(url, QLatin1String( "score" ), str);
-    KMD5 context(QString(_playerInfos->registeredName() + str).toLatin1());
-    Manager::addToQueryURL(url, QLatin1String( "check" ), QLatin1String( context.hexDigest() ));
+    QCryptographicHash context(QCryptographicHash::Md5);
+    context.addData(QString(_playerInfos->registeredName() + str).toLatin1());
+    Manager::addToQueryURL(url, QLatin1String( "check" ), QLatin1String( context.result().toHex() ));
 
     return doQuery(url, widget);
 }
